<?php
$options_methods  = array(
        
        "constructor" => array(
                "description" => "The rgraph_options constructor builds an rgraph_options object",
                "function" => "rgraph_options (&#36;ini_file = null)",
                "parameter" => "&quot;&#36;ini_file&quot; is optional, file must exist and contain valid RGraph properties. These properties will be used as default chart properties.",
                 "returns" => "A rgraph_options object",
                "notes" => "Using an ini-file is recommended, if you want to use other defaults than RGraph offers.",
                "example" => "&#36;options = new rgraph_options(&quot;default.ini&quot;);"
        ),
        "set_option" => array(
                "description" => "With this method a chart property will be defined",
                "function" => "set_option (&#36;option, &#36;option_value, &#36;force=false)",
                "parameter" => "&quot;&#36;option&quot; should be a valid RGraph option name.
                <br />&quot;&#36;option_value&quot; must be a valid options parameter with correct type.
                <br />if &quot;&#36;force&quot; set to true option will be set without any further checks",
                "returns" => "&quot;true&quot; if option set<br>&quot;-1&quot; if option name is not found,
                <br>&quot;false&quot; if option value is of wrong type",
                "notes" => "set_option does check for correct type, but it does not check if value content is correct
                (e. g. if you set a value for a color only type &quot;string&quot; is checked but not if the color value ist correct.",
                "example" => "&#36;options->set_option(&quot;variant&quot;,&quot;3d&quot;);"
        ),
        "set_optionsviaFile" => array(
                "description" => "rgraph_options are built using property settings from an ini-file.",
                "function" => "set_optionsviaFile (&#36;ini_file)",
                "parameter" => "&quot;&#36;ini_file&quot; must exist and contain valid RGraph properties. These properties will be used as default chart properties.",
                "returns" => "&quot;true&quot; if all options set
                <br>&quot;-1&quot if file does not exist or is not found
                <br>&quot;false&quot; if content of ini-file has wrong format.
                <br>&quot;2&quot; if only part of options set",
                "notes" => "ini-file entries have a format of  &quot;<i>property-name</i>=<i>property-value</i>&quot.
                An array must contain comma separated values and enclosed with double quotes. Multiple arrays must be separated by character &quot;|&quot;.",
                "example" => "&#36;options-set_optionsviaFile (&#36;ini_file),"
        ),
        "get_option" => array(
                "description" => "Use this method to retrieve a defined value of an chart property",
                "function" => "get_option(&#36;option)",
                "parameter" => "&quot;&#36;option&quot; name of property to retrieve",
                "returns" => "defined value, array of values or null",
                "notes" => "",
                "example" => "&#36;value = &#36;options->get_option(&quot;title&quot;)"
        ),
        "get_option_type" => array(
                "description" => "Use this method to retrieve the required type for a value of a property",
                "function" => "get_option_type(&#36;option)",
                "parameter" => "&quot;&#36;option&quot; name of property to retrieve",
                "returns" => "string - indicating type of property <br>&quot;-1&quot; if name is not a known (valid) property",
                "notes" => "this method does a check on all known properties of rgraph_options",
                "example" => "&#36;type = &#36;options->get_option_type(&quot;title&quot;)"
        ),
        "getResponsiveFunction" => array(
                "description" => "With this method you construct a function which allows how a chart should
                be displayed if browser size (client size) is changed or if you are using a device
                like smartphone or tablet with smaller screensizes.",
                "function" => "getResponsiveFunction(&#36;responsive_options)",
                "parameter" => "&quot;&#36;responsive_options&quot; array of responsive properties. Parameter consists of 5 values:
                <ol><li>scale factor for resizing chart's properties
                <li>small client  size
                <li>large client size
                <li>width of canvas
                <li>height of canvas
                </ol>",
                "returns" => "string - containing responsive fucntion",
                "notes" => "scale can be set from 0.1 to 0.5, large-value must be greater than small-value.
                <br>Following properties are rescaled besides size of canvas:
                 <ul><li>textSize</li>
                <li>titleSize</li>
                <li>titleTopSize</li>
                <li>titleBottomSize</li>
                <li>titleLeftSize</li>
                <li>titleRightSize</li>
                <li>xaxisTitleSize</li>
                <li>yaxisTitleSize</li>
                <li>xaxisLabelsSize</li>
                <li>yaxisLabelsSize</li>
                <li>labelsValueSize</li>
                <li>labelsValueTextSize</li>
                <li>labelsInbarSize</li>
                <li>labelsIngraphSize</li>
                <li>labelsAboveSize</li>
                <li>labelsAngledSize</li>
                <li>labelsAngledDownSize</li>
                <li>labelsAngledUpSize</li>
                <li>labelsAngledLevelSize</li>
                <li>marginTop</li>
                <li>marginBottom</li>
                <li>marginRight</li>
                <li>marginLeft</li>
                <li>radius</li>
                <li>bubbleWidth</li>
                <li>tickmarksSize</li></ul>",
                "example" => "&#36;parm = array(0.3,990,1200,&#36;width,&#36;height);<br>&#36;function = &#36;options->getResponsiveFunction(&#36parm);"
        ),
        "getResponsiveOption" => array(
                "description" => "With this method you construct options which allows how a chart should
                be displayed if browser size (client size) is changed or if you are using a device
                like smartphone or tablet with smaller screensizes.",
                "function" => "getResponsiveOption(&#36;responsive_options)",
                "parameter" => "&quot;&#36;responsive_options&quot; array of responsive properties. Parameter consists of 5 values:
                <ol><li>scale factor for resizing chart's properties
                <li>small client  size
                <li>large client size
                <li>width of canvas
                <li>height of canvas
                </ol>",
                "returns" => "string - containing responsive options",
                "notes" => "scale can be set from 0.1 to 0.5, large-value must be greater than small-value.
                <br>Following properties are rescaled besides size of canvas:
                 <ul><li>textSize</li>
                <li>titleSize</li>
                <li>titleTopSize</li>
                <li>titleBottomSize</li>
                <li>titleLeftSize</li>
                <li>titleRightSize</li>
                <li>xaxisTitleSize</li>
                <li>yaxisTitleSize</li>
                <li>xaxisLabelsSize</li>
                <li>yaxisLabelsSize</li>
                <li>labelsValueSize</li>
                <li>labelsValueTextSize</li>
                <li>labelsInbarSize</li>
                <li>labelsIngraphSize</li>
                <li>labelsAboveSize</li>
                <li>labelsAngledSize</li>
                <li>labelsAngledDownSize</li>
                <li>labelsAngledUpSize</li>
                <li>labelsAngledLevelSize</li>
                <li>marginTop</li>
                <li>marginBottom</li>
                <li>marginRight</li>
                <li>marginLeft</li>
                <li>radius</li>
                <li>bubbleWidth</li>
                <li>tickmarksSize</li></ul>
                <br>This function has been introducef with RGraph version 6.13",
                "example" => "&#36;parm = array(0.3,990,1200,&#36;width,&#36;height);<br>&#36;responsive_option = &#36;options->getResponsiveOption(&#36parm);"
        ),
        "set_tooltip" => array(
                "description" => "set_tooltip supports creating tooltips with a template.",
                "function" => "set_tooltip (&#36;data, &#36;template=&quot;#val#&quot;, &#36;group=false)",
                "parameter" => "&quot;&#36;data&quot; defines the data set_tooltip should process.
                <br>With parameter &quot;&#36;template&quot; you define &quot;magic values&quot;. These values are used for a replacement with actual chart properties.
                <br /><br />You may specify:
                <ul><li>#val# this will be replaced by the values provided with &#36;data</li>
                <li>#label# this will be replaced by the currently set labels property</li>
                <li>#key# this will be replaced by the currently set key property</li>
                <li>#total# this will be replaced by the calculated total of a single dataseries</li>
                <li>#percent# this will be replaced by the calculated percentage of the calculated total</li></ul>
                <br />If your chart type is a &quot;Radar&quot; parameter &quot;&#36;group&quot; must be set to true",
                "returns" => "&quot;true&quot; if tooltips set
                <br>&quot;-1&quot if data is not an array",
                "notes" => "If you request &quot;#label#&quot; or &quot;#key#&quot; values for labels or key must have been defined.",
                "example" => "&#36;options->set_tooltip(&#36;data, &quot;#val#&euro; &lt;br />(#percent#% of #total#&euro;)&quot;) "
        ),
        "set_tooltip_formatted" => array(
                "description" => "set_tooltip_formatted supports creating tooltips with a template.",
                "function" => "set_tooltip_formatted (&#36;data, &#36;template=&quot;#val#&quot;, &#36;type=&quot;Bar&quot; )",
                "parameter" => "&quot;&#36;data&quot; defines the data set_tooltip should process.
                <br>With parameter &quot;&#36;template&quot; you define &quot;magic values&quot;. These values are used for a replacement with actual chart properties.
                <br /><br />You may specify:
                <ul><li>#val# this will be replaced by the values provided with &#36;data</li>
                <li>#val0# is for Gantt Charts and will be replaced by the values provided with &#36;data</li>
                <li>#val1# is for Gantt Charts and will be replaced by the values provided with &#36;data</li>
                <li>#val2# is for Gantt Charts and will be replaced by the values provided with &#36;data</li>
                <li>#label# this will be replaced by the currently set labels property</li>
                <li>#key# this will be replaced by the currently set key property</li>
                <li>#total# this will be replaced by the calculated total of a single dataseries</li>
                <li>#percent# this will be replaced by the calculated percentage of the calculated total</li></ul>
                <br />If you omit chart type it defaults to &quot;Bar&quot;.",
                "returns" => "&quot;true&quot; if tooltips have been set",
                "notes" => "If you request &quot;#label#&quot; or &quot;#key#&quot; values for labels or key must have been defined.",
                "example" => "&#36;opt->set_tooltip_formatted ( &#36;data, &quot #label#: #val#&euro; &quot;, &quot;Pie&quot; ) "
        ),
        "set_gradientColors" => array(
                "description" => "Use this method to define your colors as gradient colors.",
                "function" => "set_gradientColors (&#36;colors, &#36;gradients)",
                "parameter" => "&quot;&#36;colors&quot; must be an array of colors.
                <br>&quot;&#36;gradients&quot; must be an array of colors to be used for setting the gradient color.",
                "returns" => "&quot;true&quot; if colors set
                <br>&quot;-1&quot; if colors or gradients are not arrays.",
                "notes" => "",
                "example" => "&#36;options->set_gradientColors (&#36;colors, &#36;gradients)"
        ),
        "setColorOpacity" => array(
                "description" => "Use this method to define an opacity value to your defined colors.",
                "function" => "setColorOpacity (&#36;opacity = 0.8)",
                "parameter" => "&quot;&#36;opacity&quot; must be a value from 0 to 1, if not set it defaults to 0.8.",
                "returns" => "&quot;true&quot; if colors option has been set
                <br>&quot;-1&quot; if colors property has not been defined.",
                "notes" => "color will be transformed into rgba values.",
                "example" => "&#36;options->setColorOpacity(0.6)"
        ),
        "setOpacity" => array(
                "description" => "Use this method to define an opacity value to a single color.",
                "function" => "setOpacity (&#36;color, &#36;opacity=1.0)",
                "parameter" => "&quot;&#36;color&quot; may be a 4 byte (e.g. #fc0), a 7 byte color value (e.g. #ff0afc), or rgb- or rgba-notation of color.
                <br>&quot;&#36;opacity&quot; must be a value from 0 to 1, if not set it defaults to 1.0",
                "returns" => "rgba color
                <br>&quot;-1&quot if color is empty.
                <br>If color has not required format the parameter for color will be returned unchanged.",
                "notes" => "This function may be called statically (no need to create an rgraph_options object to use it).",
                "example" => " &#36;color = &#36;rgraph_options::setOpacity(&quot;#aa0ffc&quot;, 0.6)"
        ),
        "truncateLabels" => array(
                "description" => "with this method you may limit the size (lenght) of labels.",
                "function" => "truncateLabels (&#36;labels, &#36;size, &#36;chars)",
                "parameter" => "&quot;&#36;labels&quot; must be an array of labels
                <br >&quot;&#36;size&quot; is the maximum string length of provided labels.
                <br> with &quot;&#36;chars&quot; you may add a string indicating the truncation.",
                "returns" => "&quot;array of truncated labels&quot;
                <br>&quot;-1&quot if &#36;labels is not an array.",
                "notes" => "This function may be called statically (no need to create an rgraph_options object to use it).",
                "example" => "&#36;new_labels = &#36;rgraph_options::truncateLabels(&#36;labels,5,&quot;...&quot;)"
        ),
        "xlabelsteps" => array(
                "description" => "If you have many labels you may reduce the number of labels to be displayed",
                "function" => "xlabelsteps(&#36labels, &#36;steps)",
                "parameter" => "&#36labels - an array of labels
                 <br>&#36;steps - an interval for displaying labels. Method will set &#36;steps-1 labels to null.
                 <br>E. g. if you have 100 labels and set steps to 10 then only every 10th label will be displayable, thus resulting in only 10 labels.",
                "returns" => "a new arrary of labels or &quot;false&quot; if &#36;labels is not an arry.",
                "notes" => "This function may be called statically (no need to create an rgraph_options object to use it).",
                "example" => "&#36;new_labels=&#36;rgraph_options::xlabelsteps(&#36labels, 10)"
        ),
        "getRandomColor" => array(
                "description" => "request a color which is randomly created.",
                "function" => "getRandomColor()",
                "parameter" => "none",
                "returns" => "a 7 byte color value.",
                "notes" => "This function may be called statically (no need to create an rgraph_options object to use it).",
                "example" => "&#36;color=&#36;rgraph_options::getRandomColor ()"
        ),
        "getRandomColors" => array(
                "description" => "request an array of colors which are randomly created.",
                "function" => "getRandomColors(&#36;count)",
                "parameter" => "&quot;&#36;count&quot; - number of colors to be created",
                "returns" => "an array of 7 byte color values.",
                "notes" => "This function may be called statically (no need to create an rgraph_options object to use it).",
                "example" => "&#36;colors=&#36;rgraph_options::getRandomColors (5)"
        )
)

;