<?php
/**
 * @filesource: rgraph-chart.php
 * @author:     Joachim Schmidt - joachim.schmidt@jschmidt-systemberatung.de
 * @copyright:  Copyright (C) 2016 Joachim Schmidt. All rights reserved.
 * @license:    GNU/GPL
 * @version:    1.0
 * @abstract:   json php-helper class for rgraph charts package
 *
 */
use phpRGraph\EvalMath;
use phpRGraph\SimpleLinearRegression;

include_once dirname(__FILE__) . '/evalMath.php';

function getDataviaFormula($formula, $x_interval = 1, $x_min = 0, $x_max = 5, $max_iterations = 500)
{
    
    if (strpos($formula, "=") === false)
    {
        $user_formula = trim($formula);
        $user_formula = str_replace(",", ".", $user_formula);
    }
    else
    {
        $tmp = explode("=", $formula);
        $user_formula = trim($tmp[1]);
        $user_formula = str_replace(",", ".", $tmp[1]);
    }
    if ($user_formula)
    {
        $evalc = new EvalMath();
        $evalc->evaluate("y(x)=" . $user_formula);
    }
    else
        return null;

        if ($x_min === null)
            $x_min = 0;
            if ($x_max === null)
                $x_max = 5;
                if ($x_interval === null)
                    $x_interval = 1;

                    $x_values = array();
                    $y_values = array();
                    $max_iter = $x_max + $x_interval;

                    $j = 0;

                    for ($x_value = $x_min; $x_value <= $max_iter; $x_value += $x_interval)
                    {
                        if ($j > $max_iterations)
                        {
                            $result['error'] = " x_max=&quot;$x_max&quot;, x_interval=&quot;$x_interval&quot;. Maximum ($max_iterations)  ";
                            return $result;
                        }
                        $j++;
                        $x = round($x_value, 5);
                        $value = $evalc->e("y($x)");
                        if ($evalc->last_error)
                        {
                            $result['error'] = " &quot;$formula&quot; Error:" . $evalc->last_error;
                            return $result;
                        }
                        else
                        {
                            array_push($x_values, round($x_value, 5));
                            array_push($y_values, round($value, 5));
                        }

                    }
                    $result['x_values'] = $x_values;
                    $result['y_values'] = $y_values;
                    $result['error'] = null;
                    return $result;
}

function calculate_Regression($x_values, $data, $user_formula = null, $number_format = "en", $precision = 2)
{
    //$R = utf8_encode("R");
	$R = mb_convert_encoding("R", 'UTF-8', 'ISO-8859-1');
    $formula_out = "";

    if ($user_formula)
    {
        $formula_out = $user_formula;
        if (strpos($user_formula, "=") === false)
        {
            $user_formula = trim($user_formula);
            $user_formula = str_replace(",", ".", $user_formula);
            $formula = 4;

            $calc = new EvalMath();
            $calc->evaluate("y(x)=" . $user_formula);
        }
        else
        {
            $tmp = explode("=", $user_formula);
            $user_formula = trim($tmp[1]);
            $user_formula = str_replace(",", ".", $tmp[1]);
            if ($user_formula)
            {
                $formula = 4;
                $calc = new EvalMath();
                $calc->evaluate("y(x)=" . $user_formula);
            }
            else
                $formula = false;
        }
    }
    else
    {
        $j = 0;
        for ($k = 0; $k < count($data); $k++)
        {
            if (($data[$k] != 0 && $x_values[$k] != 0) && ($data[$k] !== null && $x_values[$k] !== null))
            {
                $test_Y[$j] = log10($data[$k]);
                $test_X[$j] = log10($x_values[$k]);
                $test_x_values[$j] = $x_values[$k];
                $j++;
            }
        }

        $slr1 = new SimpleLinearRegression($x_values, $data);
        $slr2 = new SimpleLinearRegression($test_x_values, $test_Y);
        $slr3 = new SimpleLinearRegression($test_X, $test_Y);

        // test three regression formulas:
        array_multisort($x_values, $data);

        if ($slr1)
            $tst1_R = $slr1->RSquared;
            if ($slr2)
            {
                $slr2_A_value = pow(10, $slr2->YInt);
                $slr2_B_value = pow(10, $slr2->Slope);
            }
            if ($slr3)
            {
                $slr3_A_value = pow(10, $slr3->YInt);
                $slr3_B_value = $slr3->Slope;
            }

            foreach ($x_values as $k => $x_value)
            {
                // equation: Y = a * b^X
                $slr2_value[$k] = $slr2_A_value * pow($slr2_B_value, $x_value);
                //equation: Y = a * X^b
                $slr3_value[$k] = $slr3_A_value * pow($x_value, $slr3_B_value);
            }

            $slr2_R = SimpleLinearRegression::calcR($data, $slr2_value);
            $slr3_R = SimpleLinearRegression::calcR($data, $slr3_value);

            $tst2_R = pow($slr2_R, 2);
            $tst3_R = pow($slr3_R, 2);

            $tst2_R = $slr2_R;
            $tst3_R = $slr3_R;

            if ($tst1_R > $tst2_R && $tst1_R > $tst3_R)
                $formula = 1;

                if (is_finite($tst2_R))
                {
                    if ($tst2_R > $tst1_R && $tst2_R > $tst3_R)
                        $formula = 2;
                }

                if (is_finite($tst3_R))
                {
                    if ($tst3_R > $tst1_R && $tst3_R > $tst2_R)
                        $formula = 3;
                }

                if ($formula == 1)
                {
                    if ($slr1->YInt >= 0)
                        $plus = "+";
                        else
                            $plus = "";
                            $formula_out = "y = " . formatNumber($number_format, $slr1->Slope, $precision) . "x" . "$plus" . formatNumber($number_format, $slr1->YInt, $precision);
                }
                $formula_out .= " ($R=" . formatNumber($number_format, $slr1->RSquared, $precision) . ")";
                if ($formula == 2)
                {
                    $formula_out = "y = " . formatNumber($number_format, $slr2_A_value, $precision) . " * " . formatNumber($number_format, $slr2_B_value, $precision) . "^x";
                    $formula_out .= " ($R=" . formatNumber($number_format, $slr2_R, $precision) . ")";
                }
                if ($formula == 3)
                {
                    $formula_out = "y = " . formatNumber($number_format, $slr3_A_value, $precision) . " * x^" . formatNumber($number_format, $slr3_B_value, $precision);
                    $formula_out .= " ($R=" . formatNumber($number_format, $slr3_R, $precision) . ")";
                }
    }
    if ($formula)
    {
        $values = array();
        $j = 0;

        foreach ($x_values as $k => $x_value)
        {
            if ($formula == 1)
                // equation: Y = X * $Slope + $YInt
                //$value [$k] = ($x_value * $slr1->Slope) + $slr1->YInt;
                $value[$k] = $slr1->PredictedY[$k];
                if ($formula == 2)
                    $value[$k] = $slr2_value[$k];

                    if ($formula == 3)
                        $value[$k] = $slr3_value[$k];

                        if ($formula == 4)
                        {
                            $x = round($x_value, 5);
                            $value[$k] = $calc->e("y($x)");

                            if ($calc->last_error)
                                return null;
                        }
                        if ($j == 0)
                        {
                            //$values[$j] = new scatter_value($x_value, $value[$k], "");
                            $values[$j] = array(round($x_value,3), round($value[$k],3),  null, (string)round($value[$k],$precision));
                            $j++;
                        }
                        elseif ($x_values[$k] != $x_values[$k - 1])
                        {
                            //$values[$j] = new scatter_value($x_value, $value[$k], "");
                            $values[$j] = array(round($x_value,3), round($value[$k],3), null, (string)round($value[$k],$precision));
                            $j++;
                        }
        }

        $result['values'] = $values;
        if ($formula == "4")
            $formula_out .= " ($R=" . formatNumber($number_format,  SimpleLinearRegression::calcR($data, $value), $precision) . ")";
            $result['formula'] = $formula_out;
            $calc = null;

            return $result;

    }
    return null;
    
}

function formatNumber($format, $number, $precision = 2)
{
    switch ($format)
    {
 
        case "fr":
            $string = number_format($number, $precision, ",", " ");
            for ($i = 0; $i < $precision; $i++)
                $string = rtrim($string, 0);
                $string = trim($string, ",");
                break;

        case "de":
            $string = number_format($number, $precision, ",", ".");
            for ($i = 0; $i < $precision; $i++)
                $string = rtrim($string, 0);
                $string = trim($string, ",");
                break;

        case "us":
        case "en":
            $string = number_format($number, $precision, ".", ",");
            for ($i = 0; $i < $precision; $i++)
                $string = rtrim($string, 0);
                $string = trim($string, ".");
                break;

        default:
            $string = number_format($number, $precision, ".", " ");
            for ($i = 0; $i < $precision; $i++)
                $string = rtrim($string, 0);
                $string = trim($string, ",");
                break;
    }

    return $string;
}
